import type { EmitsOptions, SetupContext, CSSProperties, PropType, ExtractPropTypes } from 'vue';
import type { VueNode, ProFieldValueType } from '@ant-design-vue/pro-utils';
import type { ProFormItemProps } from './components/FormItem';
import type { ProFieldPropsType } from '@ant-design-vue/pro-field';
export declare type EmitFn<E = EmitsOptions> = SetupContext<E>['emit'];
export declare type Recordable<T = any> = Record<string, T>;
/** 简约模式 */
/** 从服务器读取选项 */
export declare const proFormGridConfig: {
    grid: {
        type: PropType<boolean>;
    };
    /**
     * @default
     * { xs: 24 }
     */
    colProps: {
        type: PropType<Partial<ExtractPropTypes<{
            span: (StringConstructor | NumberConstructor)[];
            order: (StringConstructor | NumberConstructor)[];
            offset: (StringConstructor | NumberConstructor)[];
            push: (StringConstructor | NumberConstructor)[];
            pull: (StringConstructor | NumberConstructor)[];
            xs: {
                type: PropType<string | number | import("ant-design-vue/es/grid").ColSize>;
                default: string | number | import("ant-design-vue/es/grid").ColSize;
            };
            sm: {
                type: PropType<string | number | import("ant-design-vue/es/grid").ColSize>;
                default: string | number | import("ant-design-vue/es/grid").ColSize;
            };
            md: {
                /** 简约模式 */
                /** 从服务器读取选项 */
                type: PropType<string | number | import("ant-design-vue/es/grid").ColSize>;
                default: string | number | import("ant-design-vue/es/grid").ColSize;
            };
            lg: {
                type: PropType<string | number | import("ant-design-vue/es/grid").ColSize>;
                default: string | number | import("ant-design-vue/es/grid").ColSize;
            };
            xl: {
                type: PropType<string | number | import("ant-design-vue/es/grid").ColSize>;
                default: string | number | import("ant-design-vue/es/grid").ColSize;
            };
            xxl: {
                type: PropType<string | number | import("ant-design-vue/es/grid").ColSize>;
                /** 从服务器读取选项 */
                default: string | number | import("ant-design-vue/es/grid").ColSize;
            };
            xxxl: {
                type: PropType<string | number | import("ant-design-vue/es/grid").ColSize>;
                default: string | number | import("ant-design-vue/es/grid").ColSize;
            };
            prefixCls: StringConstructor;
            flex: (StringConstructor | NumberConstructor)[];
        }>>>;
    };
    /**
     * @default
     * { gutter: 8 }
     */
    rowProps: {
        type: PropType<Partial<ExtractPropTypes<{
            align: PropType<"stretch" | "bottom" | "top" | "middle">;
            justify: PropType<"space-around" | "space-between" | "center" | "end" | "start">;
            prefixCls: StringConstructor;
            gutter: {
                type: PropType<import("ant-design-vue/es/grid/Row").Gutter | [import("ant-design-vue/es/grid/Row").Gutter, import("ant-design-vue/es/grid/Row").Gutter]>;
                default: import("ant-design-vue/es/grid/Row").Gutter | [import("ant-design-vue/es/grid/Row").Gutter, import("ant-design-vue/es/grid/Row").Gutter];
            };
            wrap: {
                type: BooleanConstructor;
                default: any;
            };
        }>>>;
    };
};
export declare type ProFormGridConfig = Partial<ExtractPropTypes<typeof proFormGridConfig>>;
export interface ProFieldProps {
    light?: boolean;
    emptyText?: VueNode;
    label?: VueNode;
    mode?: 'read' | 'edit';
    render?: any;
    readonly?: boolean;
}
export declare type FieldProps = {
    style?: CSSProperties;
    width?: string;
};
export declare type ProFormItemCreateConfig = {
    valueType?: ProFieldValueType;
} & ProFormItemProps;
export declare type ExtendsProps = {
    /**
     * 表单占用格子数
     */
    colSize?: number;
    filedConfig?: ProFormItemCreateConfig;
};
export declare type ProFormFieldItemProps<T = Record<string, any>> = {
    /**
     * @name 设置到控件上的属性
     *
     * @example 设置select 多选
     * <ProFormSelect fieldProps={{mode:"multiple"}} />
     * @example 设置select 多选
     * <ProFormText fieldProps={{placeholder:"请输入！"}} />
     */
    fieldProps?: FieldProps & T;
} & Omit<ProFieldPropsType, 'valueType'> & Pick<ProFormGridConfig, 'colProps'> & ProFormItemProps & ExtendsProps;
